summaryrefslogtreecommitdiff
path: root/html/includes
diff options
context:
space:
mode:
authorMatthijs Kuiper <info@matthijskuiper.nl>2018-01-14 11:28:01 +0100
committerGitHub <noreply@github.com>2018-01-14 11:28:01 +0100
commit76ab07b6646c807d321274bfdfb2814cffb6af90 (patch)
tree3878861d9f6c8c70fd5d638fb3ce58857cee00d5 /html/includes
parentcbae6c7e376faf9b4a76ab0631d9da168545e41f (diff)
parent701165fded99ff9f70a4379444d9bd1432052c63 (diff)
Merge pull request #7 from sn3p/new-design4.4.0
New design
Diffstat (limited to 'html/includes')
-rw-r--r--[-rwxr-xr-x]html/includes/clanbase.php0
-rwxr-xr-xhtml/includes/config.php5
-rw-r--r--[-rwxr-xr-x]html/includes/config_pic.php24
-rw-r--r--[-rwxr-xr-x]html/includes/countries.php0
-rw-r--r--html/includes/css/themes/tooltipster-light.css12
-rw-r--r--html/includes/css/themes/tooltipster-noir.css12
-rw-r--r--html/includes/css/themes/tooltipster-punk.css12
-rw-r--r--html/includes/css/themes/tooltipster-shadow.css12
-rw-r--r--html/includes/css/tooltipster.css283
-rwxr-xr-xhtml/includes/footer.php34
-rw-r--r--[-rwxr-xr-x]html/includes/ftp.php2
-rw-r--r--[-rwxr-xr-x]html/includes/ftp_class.php0
-rw-r--r--[-rwxr-xr-x]html/includes/ftp_class_native.php0
-rw-r--r--[-rwxr-xr-x]html/includes/ftp_class_pure.php0
-rw-r--r--[-rwxr-xr-x]html/includes/ftp_class_sockets.php0
-rwxr-xr-xhtml/includes/functions.php155
-rw-r--r--[-rwxr-xr-x]html/includes/geoip.inc0
-rwxr-xr-xhtml/includes/header.php74
-rw-r--r--[-rwxr-xr-x]html/includes/hints.php6
-rw-r--r--html/includes/js/adapters/standalone-framework.js18
-rw-r--r--html/includes/js/clickrows.js8
-rw-r--r--html/includes/js/clocks.js561
-rw-r--r--html/includes/js/highcharts-3d.js45
-rw-r--r--html/includes/js/highcharts-all.js471
-rw-r--r--html/includes/js/highcharts-functions.js1
-rw-r--r--html/includes/js/highcharts-more.js53
-rw-r--r--html/includes/js/highcharts.js308
-rw-r--r--html/includes/js/jquery-1.11.1.min.js4
-rw-r--r--html/includes/js/jquery.tooltipster.min.js1
-rw-r--r--html/includes/js/modules/canvas-tools.js133
-rw-r--r--html/includes/js/modules/data.js24
-rw-r--r--html/includes/js/modules/drilldown.js15
-rw-r--r--html/includes/js/modules/exporting.js23
-rw-r--r--html/includes/js/modules/funnel.js13
-rw-r--r--html/includes/js/modules/heatmap.js23
-rw-r--r--html/includes/js/modules/multicolor_series.js567
-rw-r--r--html/includes/js/modules/no-data-to-display.js12
-rw-r--r--html/includes/js/modules/solid-gauge.js13
-rw-r--r--html/includes/js/themes/dark-blue.js254
-rwxr-xr-xhtml/includes/navbar.php21
-rwxr-xr-xhtml/includes/overlib_mini.js322
-rw-r--r--html/includes/renderer-general-import.php110
-rwxr-xr-xhtml/includes/sidebar.php26
-rwxr-xr-xhtml/includes/teamstats.php333
-rw-r--r--[-rwxr-xr-x]html/includes/weaponstats.php400
45 files changed, 577 insertions, 3813 deletions
diff --git a/html/includes/clanbase.php b/html/includes/clanbase.php
index 5ad7640..5ad7640 100755..100644
--- a/html/includes/clanbase.php
+++ b/html/includes/clanbase.php
diff --git a/html/includes/config.php b/html/includes/config.php
index 11f069b..77d42fa 100755
--- a/html/includes/config.php
+++ b/html/includes/config.php
@@ -1,4 +1,5 @@
<?php
+
// Database connection details
$dbname = "";
$hostname = "";
@@ -6,13 +7,13 @@ $uname = "";
$upass = "";
// The key needed to run the import script
-$import_adminkey = 'fietsbel';
+$import_adminkey = "fietsbel";
// When runnning from the command-line (cron jobs):
// The absolute path to UTStats's home directory.
// Only needed if you're starting the importer from another directory
// Leave emtpy if unsure
-$import_homedir = '';
+$import_homedir = "";
// Use the MySQL temporary tables feature?
// Available since MySQL 3.23 - requires CREATE TEMPORARY TABLE privilege since 4.0.2
diff --git a/html/includes/countries.php b/html/includes/countries.php
index 4de8dde..4de8dde 100755..100644
--- a/html/includes/countries.php
+++ b/html/includes/countries.php
diff --git a/html/includes/css/themes/tooltipster-light.css b/html/includes/css/themes/tooltipster-light.css
deleted file mode 100644
index 945aa69..0000000
--- a/html/includes/css/themes/tooltipster-light.css
+++ /dev/null
@@ -1,12 +0,0 @@
-.tooltipster-light {
- border-radius: 5px;
- border: 1px solid #cccccc;
- background: #ededed;
- color: #666666;
-}
-.tooltipster-light .tooltipster-content {
- font-family: Arial, sans-serif;
- font-size: 14px;
- line-height: 16px;
- padding: 8px 10px;
-} \ No newline at end of file
diff --git a/html/includes/css/themes/tooltipster-noir.css b/html/includes/css/themes/tooltipster-noir.css
deleted file mode 100644
index 548b245..0000000
--- a/html/includes/css/themes/tooltipster-noir.css
+++ /dev/null
@@ -1,12 +0,0 @@
-.tooltipster-noir {
- border-radius: 0px;
- border: 3px solid #2c2c2c;
- background: #fff;
- color: #2c2c2c;
-}
-.tooltipster-noir .tooltipster-content {
- font-family: 'Georgia', serif;
- font-size: 14px;
- line-height: 16px;
- padding: 8px 10px;
-} \ No newline at end of file
diff --git a/html/includes/css/themes/tooltipster-punk.css b/html/includes/css/themes/tooltipster-punk.css
deleted file mode 100644
index 0b7362c..0000000
--- a/html/includes/css/themes/tooltipster-punk.css
+++ /dev/null
@@ -1,12 +0,0 @@
-.tooltipster-punk {
- border-radius: 5px;
- border-bottom: 3px solid #f71169;
- background: #2a2a2a;
- color: #fff;
-}
-.tooltipster-punk .tooltipster-content {
- font-family: 'Courier', monospace;
- font-size: 14px;
- line-height: 16px;
- padding: 8px 10px;
-} \ No newline at end of file
diff --git a/html/includes/css/themes/tooltipster-shadow.css b/html/includes/css/themes/tooltipster-shadow.css
deleted file mode 100644
index e869c5e..0000000
--- a/html/includes/css/themes/tooltipster-shadow.css
+++ /dev/null
@@ -1,12 +0,0 @@
-.tooltipster-shadow {
- border-radius: 5px;
- background: #fff;
- box-shadow: 0px 0px 14px rgba(0,0,0,0.3);
- color: #2c2c2c;
-}
-.tooltipster-shadow .tooltipster-content {
- font-family: 'Arial', sans-serif;
- font-size: 14px;
- line-height: 16px;
- padding: 8px 10px;
-} \ No newline at end of file
diff --git a/html/includes/css/tooltipster.css b/html/includes/css/tooltipster.css
deleted file mode 100644
index 14c70d0..0000000
--- a/html/includes/css/tooltipster.css
+++ /dev/null
@@ -1,283 +0,0 @@
-/* This is the default Tooltipster theme (feel free to modify or duplicate and create multiple themes!): */
-.tooltipster-default {
- border-radius: 5px;
- border: 1px solid #1e1e1e;
- background: -webkit-linear-gradient(#3b383b, #1e1e1e); /* For Safari 5.1 to 6.0 */
- background: -o-linear-gradient(#3b383b, #1e1e1e); /* For Opera 11.1 to 12.0 */
- background: -moz-linear-gradient(#3b383b, #1e1e1e); /* For Firefox 3.6 to 15 */
- background: linear-gradient(#3b383b, #1e1e1e); /* Standard syntax */
- color: #fff;
- cursor: pointer;
- -webkit-box-shadow: 10px 10px 26px -10px rgba(0,0,0,0.75);
- -moz-box-shadow: 10px 10px 26px -10px rgba(0,0,0,0.75);
- box-shadow: 10px 10px 26px -10px rgba(0,0,0,0.75);
- max-width: 400px;
-}
-
-/* Use this next selector to style things like font-size and line-height: */
-.tooltipster-default .tooltipster-content {
- font-family: GothamLight, sans-serif;
- font-size: 14px;
- line-height: 16px;
- padding: 8px 10px;
- overflow: hidden;
-}
-
-/* This next selector defines the color of the border on the outside of the arrow. This will automatically match the color and size of the border set on the main tooltip styles. Set display: none; if you would like a border around the tooltip but no border around the arrow */
-.tooltipster-default .tooltipster-arrow .tooltipster-arrow-border {
- /* border-color: ... !important; */
-}
-
-
-/* If you're using the icon option, use this next selector to style them */
-.tooltipster-icon {
- cursor: pointer;
- margin-left: 4px;
-}
-
-
-
-
-
-
-
-
-/* This is the base styling required to make all Tooltipsters work */
-.tooltipster-base {
- padding: 0;
- font-size: 0;
- line-height: 0;
- position: absolute;
- left: 0;
- top: 0;
- z-index: 9999999;
- pointer-events: none;
- width: auto;
- overflow: visible;
-
-}
-.tooltipster-base .tooltipster-content {
- overflow: hidden;
-}
-
-
-/* These next classes handle the styles for the little arrow attached to the tooltip. By default, the arrow will inherit the same colors and border as what is set on the main tooltip itself. */
-.tooltipster-arrow {
- display: block;
- text-align: center;
- width: 100%;
- height: 100%;
- position: absolute;
- top: 0;
- left: 0;
- z-index: -1;
-}
-.tooltipster-arrow span, .tooltipster-arrow-border {
- display: block;
- width: 0;
- height: 0;
- position: absolute;
-}
-.tooltipster-arrow-top span, .tooltipster-arrow-top-right span, .tooltipster-arrow-top-left span {
- border-left: 8px solid transparent !important;
- border-right: 8px solid transparent !important;
- border-top: 8px solid;
- bottom: -7px;
-}
-.tooltipster-arrow-top .tooltipster-arrow-border, .tooltipster-arrow-top-right .tooltipster-arrow-border, .tooltipster-arrow-top-left .tooltipster-arrow-border {
- border-left: 9px solid transparent !important;
- border-right: 9px solid transparent !important;
- border-top: 9px solid;
- bottom: -7px;
-}
-
-.tooltipster-arrow-bottom span, .tooltipster-arrow-bottom-right span, .tooltipster-arrow-bottom-left span {
- border-left: 8px solid transparent !important;
- border-right: 8px solid transparent !important;
- border-bottom: 8px solid;
- top: -7px;
-}
-.tooltipster-arrow-bottom .tooltipster-arrow-border, .tooltipster-arrow-bottom-right .tooltipster-arrow-border, .tooltipster-arrow-bottom-left .tooltipster-arrow-border {
- border-left: 9px solid transparent !important;
- border-right: 9px solid transparent !important;
- border-bottom: 9px solid;
- top: -7px;
-}
-.tooltipster-arrow-top span, .tooltipster-arrow-top .tooltipster-arrow-border, .tooltipster-arrow-bottom span, .tooltipster-arrow-bottom .tooltipster-arrow-border {
- left: 0;
- right: 0;
- margin: 0 auto;
-}
-.tooltipster-arrow-top-left span, .tooltipster-arrow-bottom-left span {
- left: 6px;
-}
-.tooltipster-arrow-top-left .tooltipster-arrow-border, .tooltipster-arrow-bottom-left .tooltipster-arrow-border {
- left: 5px;
-}
-.tooltipster-arrow-top-right span, .tooltipster-arrow-bottom-right span {
- right: 6px;
-}
-.tooltipster-arrow-top-right .tooltipster-arrow-border, .tooltipster-arrow-bottom-right .tooltipster-arrow-border {
- right: 5px;
-}
-.tooltipster-arrow-left span, .tooltipster-arrow-left .tooltipster-arrow-border {
- border-top: 8px solid transparent !important;
- border-bottom: 8px solid transparent !important;
- border-left: 8px solid;
- top: 50%;
- margin-top: -7px;
- right: -7px;
-}
-.tooltipster-arrow-left .tooltipster-arrow-border {
- border-top: 9px solid transparent !important;
- border-bottom: 9px solid transparent !important;
- border-left: 9px solid;
- margin-top: -8px;
-}
-.tooltipster-arrow-right span, .tooltipster-arrow-right .tooltipster-arrow-border {
- border-top: 8px solid transparent !important;
- border-bottom: 8px solid transparent !important;
- border-right: 8px solid;
- top: 50%;
- margin-top: -7px;
- left: -7px;
-}
-.tooltipster-arrow-right .tooltipster-arrow-border {
- border-top: 9px solid transparent !important;
- border-bottom: 9px solid transparent !important;
- border-right: 9px solid;
- margin-top: -8px;
-}
-
-
-/* Some CSS magic for the awesome animations - feel free to make your own custom animations and reference it in your Tooltipster settings! */
-
-.tooltipster-fade {
- opacity: 0;
- -webkit-transition-property: opacity;
- -moz-transition-property: opacity;
- -o-transition-property: opacity;
- -ms-transition-property: opacity;
- transition-property: opacity;
-}
-.tooltipster-fade-show {
- opacity: 1;
-}
-
-.tooltipster-grow {
- -webkit-transform: scale(0,0);
- -moz-transform: scale(0,0);
- -o-transform: scale(0,0);
- -ms-transform: scale(0,0);
- transform: scale(0,0);
- -webkit-transition-property: -webkit-transform;
- -moz-transition-property: -moz-transform;
- -o-transition-property: -o-transform;
- -ms-transition-property: -ms-transform;
- transition-property: transform;
- -webkit-backface-visibility: hidden;
-}
-.tooltipster-grow-show {
- -webkit-transform: scale(1,1);
- -moz-transform: scale(1,1);
- -o-transform: scale(1,1);
- -ms-transform: scale(1,1);
- transform: scale(1,1);
- -webkit-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
- -webkit-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -moz-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -ms-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -o-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
-}
-
-.tooltipster-swing {
- opacity: 0;
- -webkit-transform: rotateZ(4deg);
- -moz-transform: rotateZ(4deg);
- -o-transform: rotateZ(4deg);
- -ms-transform: rotateZ(4deg);
- transform: rotateZ(4deg);
- -webkit-transition-property: -webkit-transform, opacity;
- -moz-transition-property: -moz-transform;
- -o-transition-property: -o-transform;
- -ms-transition-property: -ms-transform;
- transition-property: transform;
-}
-.tooltipster-swing-show {
- opacity: 1;
- -webkit-transform: rotateZ(0deg);
- -moz-transform: rotateZ(0deg);
- -o-transform: rotateZ(0deg);
- -ms-transform: rotateZ(0deg);
- transform: rotateZ(0deg);
- -webkit-transition-timing-function: cubic-bezier(0.230, 0.635, 0.495, 1);
- -webkit-transition-timing-function: cubic-bezier(0.230, 0.635, 0.495, 2.4);
- -moz-transition-timing-function: cubic-bezier(0.230, 0.635, 0.495, 2.4);
- -ms-transition-timing-function: cubic-bezier(0.230, 0.635, 0.495, 2.4);
- -o-transition-timing-function: cubic-bezier(0.230, 0.635, 0.495, 2.4);
- transition-timing-function: cubic-bezier(0.230, 0.635, 0.495, 2.4);
-}
-
-.tooltipster-fall {
- top: 0;
- -webkit-transition-property: top;
- -moz-transition-property: top;
- -o-transition-property: top;
- -ms-transition-property: top;
- transition-property: top;
- -webkit-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
- -webkit-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -moz-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -ms-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -o-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
-}
-.tooltipster-fall-show {
-}
-.tooltipster-fall.tooltipster-dying {
- -webkit-transition-property: all;
- -moz-transition-property: all;
- -o-transition-property: all;
- -ms-transition-property: all;
- transition-property: all;
- top: 0px !important;
- opacity: 0;
-}
-
-.tooltipster-slide {
- left: -40px;
- -webkit-transition-property: left;
- -moz-transition-property: left;
- -o-transition-property: left;
- -ms-transition-property: left;
- transition-property: left;
- -webkit-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1);
- -webkit-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -moz-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -ms-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- -o-transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
- transition-timing-function: cubic-bezier(0.175, 0.885, 0.320, 1.15);
-}
-.tooltipster-slide.tooltipster-slide-show {
-}
-.tooltipster-slide.tooltipster-dying {
- -webkit-transition-property: all;
- -moz-transition-property: all;
- -o-transition-property: all;
- -ms-transition-property: all;
- transition-property: all;
- left: 0px !important;
- opacity: 0;
-}
-
-
-/* CSS transition for when contenting is changing in a tooltip that is still open. The only properties that will NOT transition are: width, height, top, and left */
-.tooltipster-content-changing {
- opacity: 0.5;
- -webkit-transform: scale(1.1, 1.1);
- -moz-transform: scale(1.1, 1.1);
- -o-transform: scale(1.1, 1.1);
- -ms-transform: scale(1.1, 1.1);
- transform: scale(1.1, 1.1);
-}
diff --git a/html/includes/footer.php b/html/includes/footer.php
index 9e3a6de..fa36ccd 100755
--- a/html/includes/footer.php
+++ b/html/includes/footer.php
@@ -1,21 +1,17 @@
-<br><br><br>
-
-<table class="box" border="0" cellpadding="1" width="720">
- <tr>
- <td class="smheading" align="center">
-
- <!-- Please leave this bit in, its the least you can do with all the work we have done :) -->
- <p>
- <a href="https://github.com/sn3p/utstats" target="_blank">
- UTStats Beta 4.3.0</a> &copy; 2005 azazel, AnthraX and toa
- </p>
-
- </td>
- </tr>
-</table>
-
-</center>
-</td></tr></tbody></table>
-</body></html>
+ <div class="footer">
+ <a href="./?p=totals">Totals</a>
+ <a href="./?p=maps">Maps</a>
+ <a href="./?p=servers">Servers</a>
+ <a href="./import.php">Import</a>
+ <a href="./admin.php">Admin</a>
+ <a href="./?p=credits">Credits</a>
+ <a href="./?p=help">Help</a>
+ <br>
+ <br>
+ <a href="https://github.com/sn3p/utstats" target="_blank">UTStats Beta 4.4.0</a>
+ &copy; <?php echo date("Y"); ?> azazel, AnthraX toa and sn3p
+ </div>
+ </body>
+</html>
<?php ob_end_flush(); ?>
diff --git a/html/includes/ftp.php b/html/includes/ftp.php
index 7e058a3..1a6e7ee 100755..100644
--- a/html/includes/ftp.php
+++ b/html/includes/ftp.php
@@ -109,7 +109,7 @@ function ftpupdate()
if (!$ftp_debug) {
- if ($html) echo'<table class="box" border="0" cellpadding="1" cellspacing="2" style="table-layout:fixed"><tr><td class="smheading" align="center" height="25" width="550" colspan="2">';
+ if ($html) echo'<table class="zebra box" border="0" cellpadding="0" cellspacing="0" style="table-layout:fixed"><tr><td class="smheading" align="center" height="25" width="550" colspan="2">';
echo "FTP Transferring Log Files...\n";
diff --git a/html/includes/ftp_class.php b/html/includes/ftp_class.php
index 5281379..5281379 100755..100644
--- a/html/includes/ftp_class.php
+++ b/html/includes/ftp_class.php
diff --git a/html/includes/ftp_class_native.php b/html/includes/ftp_class_native.php
index 4f7f1df..4f7f1df 100755..100644
--- a/html/includes/ftp_class_native.php
+++ b/html/includes/ftp_class_native.php
diff --git a/html/includes/ftp_class_pure.php b/html/includes/ftp_class_pure.php
index e7806db..e7806db 100755..100644
--- a/html/includes/ftp_class_pure.php
+++ b/html/includes/ftp_class_pure.php
diff --git a/html/includes/ftp_class_sockets.php b/html/includes/ftp_class_sockets.php
index 8cfd27f..8cfd27f 100755..100644
--- a/html/includes/ftp_class_sockets.php
+++ b/html/includes/ftp_class_sockets.php
diff --git a/html/includes/functions.php b/html/includes/functions.php
index b8cab68..aaf2635 100755
--- a/html/includes/functions.php
+++ b/html/includes/functions.php
@@ -34,16 +34,16 @@ require_once(dirname(__FILE__) .'/countries.php');
// Addslashes if magic_quotes are off
function my_addslashes($data) {
if (!get_magic_quotes_gpc()) {
- $data = addslashes($data);
+ $data = addslashes($data);
}
return $data;
}
function my_stripslashes($data) {
if (!get_magic_quotes_gpc()) {
- $data = $data;
+ $data = $data;
} else {
- $data = stripslashes($data);
+ $data = stripslashes($data);
}
return $data;
}
@@ -84,14 +84,14 @@ function my_fopen($filename, $mode, &$compression) {
if (substr($filename, -4) == '.bz2') {
if (check_extension('bz2')) {
$compression = 'bz2';
- } else {
+ } else {
return(false);
}
}
if (substr($filename, -3) == '.gz') {
if (check_extension('zlib')) {
$compression = 'zlib';
- } else {
+ } else {
return(false);
}
}
@@ -162,14 +162,12 @@ function get_dp($number) {
function sec2min($number) {
$dp = $number/60;
-
$dp = number_format($dp, 2, '.', '');
return ($dp);
}
function sec2hour($number) {
$dp = $number/3600;
-
$dp = number_format($dp, 2, '.', '');
return ($dp);
}
@@ -250,13 +248,12 @@ function btcaptime($time) {
function GetItemInfo ($itemname, $itemchunks) {
$retval = "N/A";
for ($i = 0; $i < count($itemchunks); $i++) {
- //Found this item
- if (strcasecmp($itemchunks[$i], $itemname) == 0) {
- $retval = $itemchunks[$i+1];
- }
+ //Found this item
+ if (strcasecmp($itemchunks[$i], $itemname) == 0) {
+ $retval = $itemchunks[$i+1];
+ }
}
-
- return $retval;
+ return $retval;
}
function GetMinutes($seconds) {
@@ -271,12 +268,12 @@ function GetMinutes($seconds) {
function FlagImage($country, $mini = true) {
global $a_countries;
- $width = ($mini) ? 15 : 18;
- $height = ($mini) ? 10 : 12;
+ $width = ($mini) ? 20 : 20;
+ $height = ($mini) ? 14 : 14;
if (empty($country)) return('');
- if (!file_exists("images/flags/$country.png")) return(''); //18*12
+ if (!file_exists("assets/images/flags/$country.png")) return(''); //18*12
$countryname = (isset($a_countries[$country])) ? $a_countries[$country] : '';
- return('<img src="images/flags/'. $country .'.png" width="'.$width.'" height="'.$height.'" style="border:0;" alt="'. $country .'" title="'. $countryname .'">');
+ return('<img src="assets/images/flags/'. $country .'.png" width="'.$width.'" height="'.$height.'" style="border:0;" alt="'. $country .'" title="'. $countryname .'">');
}
function RankMovement($diff) {
@@ -294,53 +291,49 @@ function RankMovement($diff) {
diff --git a/html/includes/config_pic.php b/html/includes/config_pic.php
index e70aee5..99bc089 100755..100644
--- a/html/includes/config_pic.php
+++ b/html/includes/config_pic.php
@@ -1,7 +1,6 @@
<?php
// Picture configuration file
-
// General note about colors:
// When specifying a color, you specify it's RGB values in hex (like you do in HTML).
// Example: 00FF00 = green (0 red, 255 green, 0 blue)
@@ -12,9 +11,6 @@
// Acceptable values are 00 (completely opaque) to 7F (completely transparent)
// FFFF003F will become half transparent yellow
-
-
-
$i=0;
// Enable users to use this picutre or (temporary) disable it?
$pic[$i]['enabled'] = true;
@@ -25,7 +21,7 @@ $pic[$i]['enabled'] = true;
$pic[$i]['gidrequired'] = true;
// The template picture where we're going to write stuff at
// We're searching for it in images/templates.
$pic[$i]['load']['template'] = 'basic.png';
// Create a copy of the picture and work with that copy?
// That's needed f.e. if you're using a picture with a palette of colors and want
@@ -47,12 +43,10 @@ $pic[$i]['output']['type'] = 'png';
// override the standard ;)
$pic[$i]['default']['align'] = 'left';
$pic[$i]['default']['angle'] = 0;
-$pic[$i]['default']['font'] = 'arbocrest.ttf';
+$pic[$i]['default']['font'] = 'arbocrest.ttf'; // Loaded from assets/fonts.
$pic[$i]['default']['fontcolor'] = 'FFFFFF';
$pic[$i]['default']['fontsize'] = 12;
-
-
// Now we've loaded the picture and know how to output it.
// Let's place some fancy stuff on it:
@@ -67,7 +61,7 @@ $pic[$i]['default']['fontsize'] = 12;
// inline variables are available (see below)
// align - The alignment of the text (left, center, right)
// (optional, default: left)
// fontname - The name of the TTF file (must be in images/fonts)
// (optional if you specified a default value)
// fontsize - The font size. Depending on your version of GD, this should be specified
// as the pixel size (GD1) or point size (GD2).
@@ -157,7 +151,6 @@ $pic[$i]['default']['fontsize'] = 12;
// '%PLAYERNAME%'s overall accuracy this month was %MONTH_ACC% % while it was %LMONTH_ACC% last month!'
// ==> 'Player's overall accuracy this month was 42.22 % while it was 27.52 % last month!'
-
$j=0;
$pic[$i]['process'][$j]['type'] = 'text';
$pic[$i]['process'][$j]['value'] = '%PLAYERNAME%';
@@ -197,13 +190,6 @@ $pic[$i]['process'][$j]['x_from'] = 75;
$pic[$i]['process'][$j]['y_from'] = 91;
$j++;
-
-
-
-
-
-
-
// The next picture
$i++;
@@ -234,6 +220,4 @@ $pic[$i]['process'][$j]['x_from'] = 9;
$pic[$i]['process'][$j]['y_from'] = 43;
$j++;
-
-
-?> \ No newline at end of file
+?>
@@ -25,7 +21,7 @@ $pic[$i]['enabled'] = true;
$pic[$i]['gidrequired'] = true;
// The template picture where we're going to write stuff at
-// We're searching for it in images/templates.
+// We're searching for it in assets/images/templates.
$pic[$i]['load']['template'] = 'basic.png';
// Create a copy of the picture and work with that copy?
@@ -67,7 +61,7 @@ $pic[$i]['default']['fontsize'] = 12;
// align - The alignment of the text (left, center, right)
// (optional, default: left)
-// fontname - The name of the TTF file (must be in images/fonts)
+// fontname - The name of the TTF file (must be in assets/fonts)
// (optional if you specified a default value)
// fontsize - The font size. Depending on your version of GD, this should be specified